@@ -1,4 +1,4 @@
-'''
+r'''
 # AWS PDK
 
 All documentation is located at: https://aws.github.io/aws-pdk
@@ -51,6 +51,9 @@ Please refer to [Developer Guide](./docs/developer_guides/static-website/index.m
 
 Please refer to [Developer Guide](./docs/developer_guides/type-safe-api/index.md).
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
