@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -17,7 +20,7 @@ import constructs._jsii
 import projen._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws/pdk", "0.23.39", __name__[0:-6], "pdk@0.23.39.jsii.tgz"
+    "@aws/pdk", "0.23.61", __name__[0:-6], "pdk@0.23.61.jsii.tgz"
 )
 
 __all__ = [
