@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -32,12 +35,14 @@ class UserIdentity(
         scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
+        allow_signup: typing.Optional[builtins.bool] = None,
         identity_pool_options: typing.Optional[typing.Union[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps, typing.Dict[builtins.str, typing.Any]]] = None,
         user_pool: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
+        :param allow_signup: Allow self sign up. Default: - false
         :param identity_pool_options: Configuration for the Identity Pool.
         :param user_pool: User provided Cognito UserPool. Default: - a userpool with mfa will be created.
         '''
@@ -46,7 +51,9 @@ class UserIdentity(
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = UserIdentityProps(
-            identity_pool_options=identity_pool_options, user_pool=user_pool
+            allow_signup=allow_signup,
+            identity_pool_options=identity_pool_options,
+            user_pool=user_pool,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -73,6 +80,7 @@ class UserIdentity(
     jsii_type="@aws/pdk.identity.UserIdentityProps",
     jsii_struct_bases=[],
     name_mapping={
+        "allow_signup": "allowSignup",
         "identity_pool_options": "identityPoolOptions",
         "user_pool": "userPool",
     },
@@ -81,11 +89,13 @@ class UserIdentityProps:
     def __init__(
         self,
         *,
+        allow_signup: typing.Optional[builtins.bool] = None,
         identity_pool_options: typing.Optional[typing.Union[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps, typing.Dict[builtins.str, typing.Any]]] = None,
         user_pool: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool] = None,
     ) -> None:
         '''Properties which configures the Identity Pool.
 
+        :param allow_signup: Allow self sign up. Default: - false
         :param identity_pool_options: Configuration for the Identity Pool.
         :param user_pool: User provided Cognito UserPool. Default: - a userpool with mfa will be created.
         '''
@@ -93,14 +103,26 @@ class UserIdentityProps:
             identity_pool_options = _aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps(**identity_pool_options)
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__222a3b2caa10c1bfa3835077067d8216decf681bd0f8bec700ca69ceace9e3e8)
+            check_type(argname="argument allow_signup", value=allow_signup, expected_type=type_hints["allow_signup"])
             check_type(argname="argument identity_pool_options", value=identity_pool_options, expected_type=type_hints["identity_pool_options"])
             check_type(argname="argument user_pool", value=user_pool, expected_type=type_hints["user_pool"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
+        if allow_signup is not None:
+            self._values["allow_signup"] = allow_signup
         if identity_pool_options is not None:
             self._values["identity_pool_options"] = identity_pool_options
         if user_pool is not None:
             self._values["user_pool"] = user_pool
 
+    @builtins.property
+    def allow_signup(self) -> typing.Optional[builtins.bool]:
+        '''Allow self sign up.
+
+        :default: - false
+        '''
+        result = self._values.get("allow_signup")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def identity_pool_options(
         self,
@@ -757,6 +779,7 @@ def _typecheckingstub__3dda65570bf25bbaff83417268c7c0a7e08163811a20c7a7401e4a59f
     scope: _constructs_77d1e7e8.Construct,
     id: builtins.str,
     *,
+    allow_signup: typing.Optional[builtins.bool] = None,
     identity_pool_options: typing.Optional[typing.Union[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps, typing.Dict[builtins.str, typing.Any]]] = None,
     user_pool: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool] = None,
 ) -> None:
@@ -765,6 +788,7 @@ def _typecheckingstub__3dda65570bf25bbaff83417268c7c0a7e08163811a20c7a7401e4a59f
 
 def _typecheckingstub__222a3b2caa10c1bfa3835077067d8216decf681bd0f8bec700ca69ceace9e3e8(
     *,
+    allow_signup: typing.Optional[builtins.bool] = None,
     identity_pool_options: typing.Optional[typing.Union[_aws_cdk_aws_cognito_identitypool_alpha_e0ee7798.IdentityPoolProps, typing.Dict[builtins.str, typing.Any]]] = None,
     user_pool: typing.Optional[_aws_cdk_aws_cognito_ceddda9d.UserPool] = None,
 ) -> None:
